@@ -20,7 +20,7 @@ import (
 	"bytes"
 	"crypto/tls"
 	"fmt"
-	"io/ioutil"
+	"io"
 	"net/http"
 	"os"
 	"reflect"
@@ -386,7 +386,7 @@ func TestSendRequest(t *testing.T) {
 				caller: mockClient{
 					res: &http.Response{
 						StatusCode: 401,
-						Body:       ioutil.NopCloser(bytes.NewReader([]byte(`error:["unauthorized"]`))),
+						Body:       io.NopCloser(bytes.NewReader([]byte(`error:["unauthorized"]`))),
 					},
 				},
 			},
@@ -398,7 +398,7 @@ func TestSendRequest(t *testing.T) {
 				caller: mockClient{
 					res: &http.Response{
 						StatusCode: 200,
-						Body:       ioutil.NopCloser(bytes.NewReader([]byte(vulnerabilityResponse))),
+						Body:       io.NopCloser(bytes.NewReader([]byte(vulnerabilityResponse))),
 					},
 				},
 			},
