@@ -6,5 +6,6 @@ set -o pipefail
 
 export GO111MODULE=on
 export PATH=$PATH:$(go env GOPATH)/bin
-go get -u honnef.co/go/tools/cmd/staticcheck
+go get -d honnef.co/go/tools/cmd/staticcheck
+go install honnef.co/go/tools/cmd/staticcheck
 staticcheck -f stylish ./...
